## Basic accuracy and speed tests using the python wrappers

To install the python wrappers for finufft
see ../../../docs/install.rst

Then you may run the tests as follows

```
python3 run_accuracy_tests.py
python3 run_speed_tests.py
```

The codes `accuracy_speed_tests.py` and `../examples/*` illustrate how to call
FINUFFT from python.
